from setuptools import setup

setup(name='gbdc_probability',
      version='0.1',
      description='Gaussian distributions',
      packages=['gbdc_probability'],
      author = 'Adeshola Afolabi',
      zip_safe=False)
